@@ -1,5 +1,5 @@
 package Job::Machine::DB;
-$Job::Machine::DB::VERSION = '0.25';
+$Job::Machine::DB::VERSION = '0.26';
 use strict;
 use warnings;
 use Carp qw/croak confess/;
@@ -170,9 +170,9 @@ sub fetch_task {
 	my ($self,$id) = @_;
 	$self->{current_table} = 'task';
 	my $sql = qq{
-		SELECT *
-		FROM "$self->{database_schema}".$self->{current_table}
-		JOIN "$self->{database_schema}".class USING (class_id)
+		SELECT t.*, c.name
+		FROM "$self->{database_schema}".$self->{current_table} t
+		JOIN "$self->{database_schema}".class c USING (class_id)
 		WHERE task_id=?
 	};
 	my $task = $self->select_first(sql => $sql,data => [$id]) or return;
@@ -296,7 +296,7 @@ sub get_tasks {
 	my ($where_clause, @where_args) = $self->where_clause($args{where});
 	my $order_by = $self->order_by($args{order_by});
 	my $sql = qq{
-		SELECT *
+		SELECT t.*, c.name
 		FROM "$self->{database_schema}".$self->{current_table} t
 		JOIN "$self->{database_schema}".class c USING (class_id)
 		$where_clause
@@ -485,7 +485,7 @@ Job::Machine::DB
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 NAME
 
